$wnd.rstudio.runAsyncCallback16("function Tat(a){this.a=a}\nfunction j8s(a,b){this.a=a;this.b=b;ydf.call(this)}\nfunction N7s(a,b){a.a=b;fat(a.q,J7s(a,null),a.a.file_path)}\nfunction P7s(a,b){b.slide_index==0&&lZp(a.q);a.a=b;fat(a.q,J7s(a,null),a.a.file_path)}\nfunction W7s(a){Tbh(H7s.Lnc(),Qge());qQh(a.c,new lSh,false)}\nfunction K7s(a){var b;b=qei(new rei(0,H7s.Hnc()));g6l(a.o,new j8s(a,b))}\nfunction g6l(a,b){Bbm(a,Wzy,'close_presentation_pane',new vL,b)}\nfunction V7s(a){var b;a.K._4b();!!a.a&&a.a.active&&(b=yaf(Oh(a.q.d).contentWindow),!(!oue(b1x,b)&&!oue('javascript:void(0)',b)))&&N7s(a,a.a)}\nfunction Pat(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=Dbt(a.a.b.a);vTp(a.a,a.a.a)}switch(a.c){case 1:K7s((c=a.a.a,a.b[0],c));break;case 2:P7s(a.a.a,a.b[0]);break;case 3:a.a.a.K.Z4b();break;case 4:a.a.a.K.$4b();break;case 5:V7s(a.a.a);break;case 6:W7s((b=a.a.a,a.b[0],b));break;case 7:a.a.a.K.a5b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].mn()}}\nvar r3A='Closing Presentation...',s3A='Opening Presentation...';TFd(7933,33,{},j8s);_.pA=function l8s(a){var b;qQh((b=this,a,b).a.c,new lSh,false)};_.oA=function k8s(a){Hdi(this.b,a.a?a.a.c:a.d)};var PKc=Ese(7933);TFd(8765,1,pBA);_.Hnc=function Q8s(){return r3A};_.Lnc=function V8s(){return s3A};TFd(8763,1,pBA);_.Hnc=function g9s(){return r3A};_.Lnc=function l9s(){return s3A};TFd(8764,1,pBA);_.Hnc=function y9s(){return 'Fermeture de la pr\\xE9sentation...'};_.Lnc=function D9s(){return 'Ouvrir la pr\\xE9sentation...'};TFd(461,1,Wwy);_.kn=function Sat(){Pat((new Tat(this)).a)};TFd(7231,1,uZx,Tat);_.mn=function Uat(){Pat(this.a)};var pLc=Ese(7231);qJx(fm)(16);\n//# sourceURL=rstudio-16.js\n")
